==> zio-aws-serverlessapplicationrepository_2.12-5.17.116.2-sources.jar: zio/aws/serverlessapplicationrepository/model/Tag.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class Tag(key: __string, value: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
      .builder()
      .key(__string.unwrap(key): java.lang.String)
      .value(__string.unwrap(value): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.serverlessapplicationrepository.model.Tag.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.serverlessapplicationrepository.model.Tag =
      zio.aws.serverlessapplicationrepository.model.Tag(key, value)
    def key: __string
    def value: __string
    def getKey: ZIO[Any, Nothing, __string] = ZIO.succeed(key)
    def getValue: ZIO[Any, Nothing, __string] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
  ) extends zio.aws.serverlessapplicationrepository.model.Tag.ReadOnly {
    override val key: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.key())
    override val value: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.value())
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
  ): zio.aws.serverlessapplicationrepository.model.Tag.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-serverlessapplicationrepository_2.12-5.17.211.1-sources.jar: zio/aws/serverlessapplicationrepository/model/Tag.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class Tag(key: __string, value: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
      .builder()
      .key(key: java.lang.String)
      .value(value: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.serverlessapplicationrepository.model.Tag.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.serverlessapplicationrepository.model.Tag =
      zio.aws.serverlessapplicationrepository.model.Tag(key, value)
    def key: __string
    def value: __string
    def getKey: ZIO[Any, Nothing, __string] = ZIO.succeed(key)
    def getValue: ZIO[Any, Nothing, __string] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
  ) extends zio.aws.serverlessapplicationrepository.model.Tag.ReadOnly {
    override val key: __string = impl.key(): __string
    override val value: __string = impl.value(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.Tag
  ): zio.aws.serverlessapplicationrepository.model.Tag.ReadOnly = new Wrapper(
    impl
  )
}
